@@ -1,4 +1,4 @@
-use anyhow::Result;
+use anyhow::{Context, Result};
 
 use crate::server::grpc::api::{
     spotifatius_client::SpotifatiusClient, ToggleLikedRequest,
@@ -10,7 +10,8 @@ pub struct Service {}
 impl Service {
     pub async fn toggle_liked() -> Result<()> {
         let mut client =
-            SpotifatiusClient::connect(format!("http://{ADDRESS}")).await?;
+            SpotifatiusClient::connect(format!("http://{ADDRESS}")).await
+            .context("Could not connect to monitor instance, make sure there is one running")?;
         let request = tonic::Request::new(ToggleLikedRequest {});
         let response = client.toggle_liked(request).await?;
         println!(
